<?php

//require_once( plugin_dir_path( __FILE__ ) . 'includes/class-admin-lists.php' );
require_once( plugin_dir_path( __FILE__ ) . 'includes/class-doifd-list-options.php' );
require_once( plugin_dir_path( __FILE__ ) . 'includes/class-admin-visual-filters.php' );

class DOIFD_Lists_Admin {


    protected static $instance = null;
    
    protected $plugin_screen_hook_suffix = null;

    private function __construct() {

        $plugin = DOIFD_Lists::get_instance();
        $this->plugin_slug = $plugin->get_plugin_slug();
        
        // Load admin style sheet and JavaScript.
        add_action( 'admin_enqueue_scripts', array ( $this, 'enqueue_admin_styles' ) );
        add_action( 'admin_enqueue_scripts', array ( $this, 'enqueue_admin_scripts' ) );


        // Add the options page and menu item.
        add_action('admin_menu', array($this, 'add_plugin_admin_menu'));

        // Add an action link pointing to the options page.
        $plugin_basename = plugin_basename( plugin_dir_path( __DIR__ ) . $this->plugin_slug . '.php' );

        add_filter( 'doifd_upload_fields', array ( $this, 'add_list_checkbox' ) );
        add_filter( 'doifd_validate_admin_values', array ( $this, 'add_validate_type' ) );
        add_filter( 'doifd_upload_values_formats', array ( $this, 'add_list_value_format' ) );
        add_action( 'wp_ajax_doifd_add_list', array ( $this, 'doifd_add_list' ) );
        add_action( 'doifd_download_bypass', array ( $this, 'create_list_download' ) );
        add_action( 'doifd_free_download_bypass', array ( $this, 'create_free_list_download') );
        add_action( 'admin_init', array ( $this, 'add_email_settings' ) );
    }

    // Return Instance
    public static function get_instance() {

        if ( null == self::$instance ) {
            self::$instance = new self;
        }

        return self::$instance;
    }

    //Register and enqueue admin-specific style sheet.
    public function enqueue_admin_styles() {

        if ( !isset( $this->plugin_screen_hook_suffix ) ) {
            return;
        }

        $screen = get_current_screen();
        if ( $this->plugin_screen_hook_suffix == $screen->id ) {
            wp_enqueue_style( $this->plugin_slug . '-admin-styles', plugins_url( 'assets/css/admin.css', __FILE__ ), array ( ), DOIFD_Lists::VERSION );
        }
    }

    //Register and enqueue admin-specific JavaScript.
    public function enqueue_admin_scripts() {

        if ( !isset( $this->plugin_screen_hook_suffix ) ) {
            return;
        }

        $screen = get_current_screen();
        if ( ($this->plugin_screen_hook_suffix == $screen->id) || ($screen->id == 'doifd_page_doifd-admin-menu_downloads') ) {
            wp_enqueue_script( $this->plugin_slug . '-admin-script', plugins_url( 'assets/js/doifd-list-admin.js', __FILE__ ), array ( 'jquery' ), DOIFD_Lists::VERSION );
        }
    }

    //Register the administration menu for this plugin into the WordPress Dashboard menu.
    public function add_plugin_admin_menu() {

        $this->plugin_screen_hook_suffix = add_submenu_page(
                'doifd-admin-menu', 'doifd lists', __('List Settings', $this->plugin_slug ), 'manage_options', 'doifd-admin-menu_lists', array($this, 'doifd_lab_lists_page'));
    }

    //Render the settings page for this plugin.
    public function display_plugin_admin_page() {
        include_once( 'views/admin.php' );
    }
    
    public function doifd_lab_lists_page() {

        include_once( 'views/view-admin-lists.php' );
    }
    
    public function add_email_settings() {
        
        $list_settings = new DOIFDListOptions;
        
        register_setting('doifd_list_options', 'doifd_list_options', array($this, 'validate_options'));
        add_settings_section('doifd_list_email_section', __('List Email Settings', $this->plugin_slug ), '', 'doifd_list_email') ;
        add_settings_field('doifd_list_from_email', __('List Return Email Address', $this->plugin_slug ), array($list_settings, 'from_list_email_address_field'), 'doifd_list_email', 'doifd_list_email_section');
        add_settings_field('doifd_list_email_name', __('List Email From', $this->plugin_slug ), array($list_settings, 'from_list_email_name_field'), 'doifd_list_email', 'doifd_list_email_section');
        
        /* If premium version add HTML and Subject Line Fields */
        if ( is_plugin_active( 'premium-double-opt-in-for-download/premium-double-opt-in-for-download.php' ) ) {
        add_settings_field('doifd_list_email_subject', __('List Email Subject Line', $this->plugin_slug ), array($list_settings, 'list_email_subject_field'), 'doifd_list_email', 'doifd_list_email_section');
        add_settings_field('doifd_list_send_html', __('List Send HTML Verfication Email', $this->plugin_slug ), array($list_settings, 'list_email_send_html'), 'doifd_list_email', 'doifd_list_email_section');
        }
        
        add_settings_field('doifd_list_email_message', __('List Verification Email:', $this->plugin_slug ), array($list_settings, 'list_email_message_field'), 'doifd_list_email', 'doifd_list_email_section');
    }

    public function add_list_checkbox( $output ) {

        $output = '<tr valign="top">
                   <th scope="row"><label for="file">' . __( 'Choose Type', $this->plugin_slug ) . '<span> *</span>: </label></th>
                   <td>
                   <div id="doifd_lab_admin_options">
                   <input type="radio" id="type" name="type" class="this_is_a_list" value="1" /> ' . __( 'This is a Mailing List', $this->plugin_slug ) . '<br />
                   <input type="radio" id="type" name="type" class="this_is_a_download" value="0" checked/> ' . __( 'This is a Download', $this->plugin_slug ) . '
                   </div>
                   </td>
                   </tr>';

        return $output;
    }

    public function add_validate_type( $valid ) {

            $validate_type = array (
                $valid[ 'type' ] = preg_replace( '/[^0-9]/', '', $_POST[ 'type' ] )
            );

            // combine the two arrays
            $valid = array_merge( $validate_type, $valid );

            return $valid;

    }
    
    public function validate_options( $input ) {

        $valid = array();
        
        $valid[ 'list_email_name' ] = preg_replace( '/[^ \w]+/', '', $input[ 'list_email_name' ] );
            
        $valid[ 'list_email_subject' ] = sanitize_text_field( $input[ 'list_email_subject' ] );
            
        $valid[ 'list_send_html' ] = preg_replace( '/[^0-9]/', '', $input[ 'list_send_html' ] );

        $valid[ 'list_from_email' ] = $input[ 'list_from_email' ];

        $valid[ 'list_email_message' ] = $input[ 'list_email_message' ];

            return $valid;

    }
    
    public function create_list_download() {
        
            global $wpdb;
            
             /* Get the wpnonce from the form and verify it's coming from our form, if not, die */
             if ( !wp_verify_nonce( $_POST[ '_wpnonce' ], 'doifd-add-download-nonce' ) )
                    wp_die( 'Security check' );

            /* Check to see if it's coming from the upload form and the user has the privileges to upload a file */

            if ( current_user_can( 'manage_options' ) ) {

                $clean = DoifdAdminValidation::admin_form_upload_validation($_POST);

                /* Get file extension and assign to variable */

                $doifd_extension = substr( strrchr( $_FILES[ 'file' ][ 'name' ], '.' ), 1 );

                if ( empty( $clean['name'] ) && ($clean['type'] == '0') ) {

                    $text = __( 'Please name your file.', $this->plugin_slug );

                    echo '<div class="doifd_error_msg">' . $text . '</div>';
                    die(); /* Added to suppress the Ajax success response */
                }
                
                if ( empty( $clean['name'] ) && ($clean['type'] == '1') ) {

                    $text = __( 'Please name your list.', $this->plugin_slug );

                    echo '<div class="doifd_error_msg">' . $text . '</div>';
                    die(); /* Added to suppress the Ajax success response */
                }

                /* If there is no Landing Page Id selected show message */

                if ( empty( $clean[ 'doifd_download_landing_page' ] ) ) {

                    $text = __( 'Please select a Landing Page.', $this->plugin_slug );

                    echo '<div class="doifd_error_msg">' . $text . '</div>';
                    die(); /* Added to suppress the Ajax success response */
                }

                /* If the file name is empty show error message */
                if (( $clean['type'] == '0' ) && ( empty( $_FILES[ 'file' ][ 'name' ] ) ) ) {

                    $text = __( 'Please select a file to upload.', $this->plugin_slug );

                    echo '<div class="doifd_error_msg">' . $text . '</div>';
                    die(); /* Added to suppress the Ajax success response */
                }

                /* Check to make sure that the file extension is one that is allowed by this plugin. If not, show error message */
                if ( ( $clean['type'] == '0' ) && ($doifd_extension != "jpg") && ($doifd_extension != "jpeg") && ($doifd_extension != "gif") && ($doifd_extension != "png") && ($doifd_extension != "bmp") && ($doifd_extension != "pdf") && ($doifd_extension != "zip") && ($doifd_extension != "doc") && ($doifd_extension != "docx") && ($doifd_extension != "mp3") ) {

                    $text = __( 'Unknown File Type (.jpg, .jpeg, .png, .bmp, .gif, .pdf, .zip, .doc, .docx, .mp3 only).', $this->plugin_slug );

                    echo '<div class="doifd_error_msg">' . $text . '</div>';
                    die(); /* Added to suppress the Ajax success response */
                }
                
                if ( ( $clean['type'] == '0' ) && ( !$_FILES[ 'file' ][ 'error' ] == 0 ) ) {

                    $error_types = array (
                        1 => 'The uploaded file exceeds the upload_max_filesize directive in php.ini.',
                        2 => 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.',
                        3 => 'The uploaded file was only partially uploaded.',
                        4 => 'No file was uploaded.',
                        5 => 'Missing a temporary folder.',
                        6 => 'Failed to write file to disk.',
                        7 => 'A PHP extension stopped the file upload.'
                    );
                    $error_message = $error_types[ $_FILES[ 'file' ][ 'error' ] ];

                    echo '<div class="doifd_error_msg">' . $error_message . '</div>';
                    die(); /* Added to suppress the Ajax success response */
                }
                    
                    if ( $clean['type'] == '0' ) {

                    /* Rename the file to a radom file name to avoid duplicate file names */

                    $doifd_lab_file_name = 'doifd_' . uniqid( mt_rand( 3, 5 ) ) . '_' . time() . '.' . $doifd_extension;

                    /* upload file to Download directory */
                    
                    $move = new DoifdDownloads();
                    $doifd_lab_upload = $move->move_file( DOUBLE_OPT_IN_FOR_DOWNLOAD_DOWNLOAD_DIR, $doifd_lab_file_name, $_FILES[ 'file' ][ 'tmp_name' ] );

                    /* If upload was unsuccessful send message to admin */

                    if ( $doifd_lab_upload == 0 ) {

                        $text = __( 'There was an error uploading your new file', $this->plugin_slug );

                        echo '<div class="doifd_error_msg">' . $text . '</div>';
                        die(); /* Added to suppress the Ajax success response */
                    }

                    /* If the download folder does not exist show this error message */
                    elseif ( $doifd_lab_upload == 2 ) {

                        $text = __( 'The download directory does not exist.', $this->plugin_slug ) . '<br />' . __( 'Check your folder permissions and try reactivating the plugin.', $this->plugin_slug );

                        echo '<div class="doifd_error_msg">' . $text . '</div>';
                        die(); /* Added to suppress the Ajax success response */
                    }

                    /* If the download folder is not writable show error message */
                    elseif ( $doifd_lab_upload == 3 ) {

                        $text = __( 'The download directory exists but is not writable. Check your folder permissions and try reactivating the plugin', $this->plugin_slug );

                        echo '<div class="doifd_error_msg">' . $text . '</div>';
                        die(); /* Added to suppress the Ajax success response */
                    }

                    /* If upload successful insert into download table and show success message */
                    elseif ( $doifd_lab_upload == 1 ) {

                        /* Put values into an array */

                        $upload_values = array (
                            'doifd_download_name' => $clean[ 'name' ],
                            'doifd_download_file_name' => $doifd_lab_file_name,
                            'doifd_download_mailchimp_list_id' => $clean[ 'doifd_download_mailchimp_list_id' ],
                            'doifd_download_mailchimp_list_name' => $clean[ 'doifd_download_mailchimp_list_name' ],
                            'doifd_download_constant_contact_list_id' => $clean[ 'doifd_download_constant_contact_list_id' ],
                            'doifd_download_constant_contact_list_name' => $clean[ 'doifd_download_constant_contact_list_name' ],
                            'doifd_download_landing_page' => $clean[ 'doifd_download_landing_page' ],
                            'doifd_download_type' => '0',
                            'time' => current_time( 'mysql', 0 )
                        );

                        $upload_values_formats = array (
                            '%s',
                            '%s',
                            '%s',
                            '%s',
                            '%s',
                            '%s',
                            '%s',
                            '%s',
                            '%s'
                        );
                        

                        /* Insert array values into the download table */

                        $wpdb->insert( $wpdb->prefix . 'doifd_lab_downloads', $upload_values, $upload_values_formats );

                        /* Show success message */

                        $text = __( 'Download Uploaded Successfully', $this->plugin_slug );

                        echo '<div class="doifd_succeed_msg" >' . $text . '</div>';
                        die(); /* Added to suppress the Ajax success response */
                    }
                    
                    } else {
                        
                        $upload_values = array (
                            'doifd_download_name' => $clean[ 'name' ],
                            'doifd_download_mailchimp_list_id' => $clean[ 'doifd_download_mailchimp_list_id' ],
                            'doifd_download_mailchimp_list_name' => $clean[ 'doifd_download_mailchimp_list_name' ],
                            'doifd_download_constant_contact_list_id' => $clean[ 'doifd_download_constant_contact_list_id' ],
                            'doifd_download_constant_contact_list_name' => $clean[ 'doifd_download_constant_contact_list_name' ],
                            'doifd_download_landing_page' => $clean[ 'doifd_download_landing_page' ],
                            'doifd_download_type' => '1',
                            'time' => current_time( 'mysql', 0 )
                        );

                        $upload_values_formats = array (
                            '%s',
                            '%s',
                            '%s',
                            '%s',
                            '%s',
                            '%s',
                            '%s',
                            '%s'
                        );
                        

                        /* Insert array values into the download table */

                        $wpdb->insert( $wpdb->prefix . 'doifd_lab_downloads', $upload_values, $upload_values_formats );

                        /* Show success message */

                        $text = __( 'List Created Successfully', $this->plugin_slug );

                        echo '<div class="doifd_succeed_msg" >' . $text . '</div>';
                        die(); /* Added to suppress the Ajax success response */
                        
                    }

            }  else {

                        /* Show error message if upload failed */

                        $text = __( 'Error Uploading File', $this->plugin_slug );

                        echo $text;
                        die(); /* Added to suppress the Ajax success response */
                    }
        }
        
        public function create_free_list_download() {

             global $wpdb;

            /* Assign the return back link to a variable */

            $rb = __ ( 'Return Back', $this->plugin_slug  );

            /* Check to see if it's coming from the upload form and the user has the privileges to upload a file */

            if ( isset ( $_POST[ 'upload' ] ) && ( current_user_can ( 'manage_options' ) ) ) {
                

                /* Get the wpnonce from the form and verify it's coming from our form, if not, die */
                
                $type = $_POST[ 'type' ];

                $doifd_lab_nonce = $_POST[ '_wpnonce' ];

                if ( !wp_verify_nonce ( $doifd_lab_nonce, 'doifd-add-download-nonce' ) ) wp_die ( 'Security check' );

                /* Clean and sanitize Download name field */

                $clean_doifd_lab_name = sanitize_text_field ( $_POST[ 'name' ] );
                
                /* clean and sanitize download landing page id */

                $doifd_clean_download_landing_page = preg_replace( '/[^0-9]/', '', $_POST[ 'doifd_download_landing_page' ] );

                /* Assign file name to variable */

                $doifd_lab_current_image = $_FILES[ 'userfile' ][ 'name' ];
                

                /* Get file extension and assign to variable */

                $clean_doifd_lab_extension = substr ( strrchr ( $doifd_lab_current_image, '.' ), 1 );

                /* If file name is empty after being sanitized show error message */

                if ( ( empty ( $clean_doifd_lab_name ) ) && ($type == '0') ) {

                    $text = __ ( 'Please name your file.', $this->plugin_slug  );

                    echo '<div id="message" class="error"><p><strong>' . $text . '  <a href="' . str_replace ( '%7E', '~', $_SERVER[ 'REQUEST_URI' ] ) . '">' . $rb . '</a></p></strong></div>';
                }
                
                if ( ( empty ( $clean_doifd_lab_name ) ) && ($type == '1') ) {

                    $text = __ ( 'Please name your list.', $this->plugin_slug  );

                    echo '<div id="message" class="error"><p><strong>' . $text . '  <a href="' . str_replace ( '%7E', '~', $_SERVER[ 'REQUEST_URI' ] ) . '">' . $rb . '</a></p></strong></div>';
                }
                
               /* If there is no Landing Page Id selected show message */
                
                if ( empty( $doifd_clean_download_landing_page ) ) {

                    $text = __( 'Please select a Landing Page.', $this->plugin_slug  );

                    echo '<div id="message" class="error"><p><strong>' . $text . '</strong></p></div>';

                }

                /* If the file name is empty show error message */ 
                
                elseif ( ( empty ( $_FILES[ 'userfile' ][ 'tmp_name' ] ) ) && ($type == '0') ) {

                    $text = __ ( 'Please select a file to upload', $this->plugin_slug  );

                    echo '<div id="message" class="error"><p><strong>' . $text . '  <a href="' . str_replace ( '%7E', '~', $_SERVER[ 'REQUEST_URI' ] ) . '">' . $rb . '</a></strong></p></div>';
                }

                /* Check to make sure that the file extension is one that is allowed by this plugin. If not, show error message */ 
                
                elseif ( ($type == '0') && ($clean_doifd_lab_extension != "jpg") && ($clean_doifd_lab_extension != "jpeg") && ($clean_doifd_lab_extension != "gif") && ($clean_doifd_lab_extension != "png") && ($clean_doifd_lab_extension != "bmp") && ($clean_doifd_lab_extension != "pdf") && ($clean_doifd_lab_extension != "zip") && ($clean_doifd_lab_extension != "doc") && ($clean_doifd_lab_extension != "docx") && ($clean_doifd_lab_extension != "mp3") ) {

                    $text = __ ( 'Unknown File Type (.jpg, .jpeg, .png, .bmp, .gif, .pdf, .zip, .doc, .docx, .mp3 only).', $this->plugin_slug  );

                    echo '<div id="message" class="error"><p><strong>' . $text . '  <a href="' . str_replace ( '%7E', '~', $_SERVER[ 'REQUEST_URI' ] ) . '">' . $rb . '</a></strong></p></div>';
                } else {

                    if ($type == '0') {
                    
                    /* Rename the file to a radom file name to avoid duplicate file names */

                    $doifd_lab_file_name = 'doifd_' . uniqid ( mt_rand ( 3, 5 ) ) . '_' . time () . '.' . $clean_doifd_lab_extension;

                    /* upload file to Download directory */

                    $move = new DoifdDownloads();
                    $doifd_lab_upload = $move->move_file( DOUBLE_OPT_IN_FOR_DOWNLOAD_DOWNLOAD_DIR, $doifd_lab_file_name, $_FILES[ 'userfile' ][ 'tmp_name' ] );

                    /* If upload was unsuccessful send message to admin */

                    if ( $doifd_lab_upload == 0 ) {

                        $text = __ ( 'There was an error uploading your new file', $this->plugin_slug  );

                        echo '<div id="message" class="error"><p><strong>' . $text . '  <a href="' . str_replace ( '%7E', '~', $_SERVER[ 'REQUEST_URI' ] ) . '">' . $rb . '</a></strong></p></div>';
                    }

                    /* If the download folder does not exist show this error message */ 
                    
                    elseif ( $doifd_lab_upload == 2 ) {

                        $text = __ ( 'The download directory does not exist. Check your permissions and try reactivating the plugin', $this->plugin_slug  );

                        echo '<div id="message" class="error"><p><strong>' . $text . '  <a href="' . str_replace ( '%7E', '~', $_SERVER[ 'REQUEST_URI' ] ) . '">' . $rb . '</a></p></strong></div>';
                    }

                    /* If the download folder is not writable show error message */ 
                    
                    elseif ( $doifd_lab_upload == 3 ) {

                        $text = __ ( 'The download directory exists but is not writable. Check your folder permissions and try reactivating the plugin', $this->plugin_slug  );

                        echo '<div id="message" class="error"><p><strong>' . $text . '  <a href="' . str_replace ( '%7E', '~', $_SERVER[ 'REQUEST_URI' ] ) . '">' . $rb . '</a></p></strong></div>';
                    }

                    /* If upload successful insert into download table and show success message */ 
                    
                    elseif ( $doifd_lab_upload == 1 ) {

                        /* Put values into an array */

                        $values = array(
                            'doifd_download_name' => $clean_doifd_lab_name,
                            'doifd_download_file_name' => $doifd_lab_file_name,
                            'doifd_download_landing_page' => $doifd_clean_download_landing_page,
                            'doifd_download_type' => '0',
                            'time' => current_time ( 'mysql', 0 )
                        );

                        $values_formats = array(
                            '%s',
                            '%s',
                            '%s',
                            '%s'
                        );

                        /* Insert array values into the download table */

                        $wpdb->insert ( $wpdb->prefix . 'doifd_lab_downloads', $values, $values_formats );

                        /* Show success message */

                        $text = __ ( 'File Uploaded Successfully', $this->plugin_slug  );

                        echo '<div class="updated"><strong>' . $text . ' <a href="' . str_replace ( '%7E', '~', $_SERVER[ 'REQUEST_URI' ] ) . '">' . $rb . '</a></strong></div>';
                    
                    }
                    
                    }
                        
                        
                     if ( $type == '1' ) {   
                        
                        
                         /* Put values into an array */

                        $values = array(
                            'doifd_download_name' => $clean_doifd_lab_name,
                            'doifd_download_landing_page' => $doifd_clean_download_landing_page,
                            'doifd_download_type' => '1',
                            'time' => current_time ( 'mysql', 0 )
                        );

                        $values_formats = array(
                            '%s',
                            '%s',
                            '%s'
                        );

                        /* Insert array values into the download table */

                        $wpdb->insert ( $wpdb->prefix . 'doifd_lab_downloads', $values, $values_formats );

                        /* Show success message */

                        $text = __ ( 'List Created Successfully', $this->plugin_slug  );

                        echo '<div class="updated"><strong>' . $text . ' <a href="' . str_replace ( '%7E', '~', $_SERVER[ 'REQUEST_URI' ] ) . '">' . $rb . '</a></strong></div>';
                        
                     }
                     
                }
                
            }
                        
                }
            }
?>