<?php

/**
 * DOIFD Lists
 *
 * @package   DOIFD List
 * @author    LAB Web Development <support@doubleoptinfordownload.com>
 * @license   GPL-2.0+
 * @link      http://www.labwebdevelopment.com
 * @copyright 2014 LAB Web Development
 */
include_once ( plugin_dir_path( __FILE__ ) . '/includes/class-doifd-list-send-email.php' );
include_once ( plugin_dir_path( __FILE__ ) . '/includes/class-doifd-list-landing-page.php' );
include_once ( plugin_dir_path( __FILE__ ) . '/includes/class-doifd-list-verify-email.php');

class DOIFD_Lists {

    const VERSION = '1.0.1';

    protected $plugin_slug = 'doifd-lists';
    protected static $instance = null;

    private function __construct() {

        // Load plugin text domain
        add_action( 'init', array ( $this, 'load_plugin_textdomain' ) );

        // Look to see if DOIFD is installed
        add_action( 'admin_init', array ( $this, 'look_for_DOIFD' ) );

        // Activate plugin when new blog is added
        add_action( 'wpmu_new_blog', array ( $this, 'activate_new_site' ) );

        /* Define custom actions. */
        add_action( 'activated_plugin', array ( $this, 'save_activation_error_lists' ) );

        /* Define custom filters */

        add_filter( 'doifd_success_msg', array ( $this, 'new_success_msg' ), 10, 2 );
        add_filter( 'doifd_widget_success_msg', array ( $this, 'new_widget_success_msg' ), 10, 2 );
        add_filter( 'doifd_admin_email_subject', array ( $this, 'change_admin_email_subject' ), 10, 2 );
    }

    /* Return the plugin slug. */

    public function get_plugin_slug() {
        return $this->plugin_slug;
    }

    /* Return an instance of this class. */

    public static function get_instance() {

        /* If the single instance hasn't been set, set it now. */
        if ( null == self::$instance ) {
            self::$instance = new self;
        }

        return self::$instance;
    }

    /**
     * Fired when the plugin is activated.
     * @param    boolean    $network_wide    True if WPMU superadmin uses
     *                                       "Network Activate" action, false if
     *                                       WPMU is disabled or plugin is
     *                                       activated on an individual blog.
     */
    public static function activate( $network_wide ) {

        if ( function_exists( 'is_multisite' ) && is_multisite() ) {

            if ( $network_wide ) {

                // Get all blog ids
                $blog_ids = self::get_blog_ids();

                foreach ( $blog_ids as $blog_id ) {

                    switch_to_blog( $blog_id );
                    self::single_activate();
                }

                restore_current_blog();
            }
            else {
                self::single_activate();
            }
        }
        else {
            self::single_activate();
        }
    }

    /**
     * Fired when the plugin is deactivated.
     * @param    boolean    $network_wide    True if WPMU superadmin uses
     *                                       "Network Deactivate" action, false if
     *                                       WPMU is disabled or plugin is
     *                                       deactivated on an individual blog.
     */
    public static function deactivate( $network_wide ) {

        if ( function_exists( 'is_multisite' ) && is_multisite() ) {

            if ( $network_wide ) {

                // Get all blog ids
                $blog_ids = self::get_blog_ids();

                foreach ( $blog_ids as $blog_id ) {

                    switch_to_blog( $blog_id );
                    self::single_deactivate();
                }

                restore_current_blog();
            }
            else {
                self::single_deactivate();
            }
        }
        else {
            self::single_deactivate();
        }
    }

    // Fired when a new site is activated with a WPMU environment.
    // @param    int    $blog_id    ID of the new blog.
    public function activate_new_site( $blog_id ) {

        if ( 1 !== did_action( 'wpmu_new_blog' ) ) {
            return;
        }

        switch_to_blog( $blog_id );
        self::single_activate();
        restore_current_blog();
    }

    /**
     * Get all blog ids of blogs in the current network that are:
     * - not archived
     * - not spam
     * - not deleted
     *
     * @since    1.0.0
     *
     * @return   array|false    The blog ids, false if no matches.
     */
    private static function get_blog_ids() {

        global $wpdb;

        // get an array of blog ids
        $sql = "SELECT blog_id FROM $wpdb->blogs
			WHERE archived = '0' AND spam = '0'
			AND deleted = '0'";

        return $wpdb->get_col( $sql );
    }

    public static function look_for_DOIFD() {

        if ( !class_exists( 'DOIFD' ) ) {
            add_action( 'all_admin_notices', array ( 'Doifd_Lists', 'needDOIFDMessage' ) );

            deactivate_plugins( DOIFD );

        }
    }

    public static function showDOIFDListMessage( $message, $errormsg = false ) {

        if ( $errormsg ) {
            echo '<div id="message" class="error">';
        }
        else {
            echo '<div id="message" class="updated fade">';
        }

        echo "<p><strong>$message</strong></p></div>";
    }

    public static function needDOIFDMessage() {

        self::showDOIFDListMessage( __( 'DOIFD-Lists requires Double OPT-IN For Download Version 1.1.4 or Premium Version 1.1.0 or higher to work.', 'double-opt-in-for-download' ), true );
    }

    public function detect_plugin_deactivation( ) {

        if ( !class_exists( 'DOIFD' ) ) {
            deactivate_plugins( DOIFD );
        }
    }

    /* Fired for each blog when the plugin is activated. */

    private static function single_activate() {

        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

        global $wpdb;

        /* Get Version number from wordpress database. */
        $doifd_list_ver = get_option( 'doifd_list_version' );

        if ( $doifd_list_ver != self::VERSION ) {

            update_option( 'doifd_list_version', self::VERSION );

            $sql = "CREATE TABLE {$wpdb->prefix}doifd_lab_downloads (
                        doifd_download_type TINYINT(1) DEFAULT '0' NOT NULL
                        );";
            dbDelta( $sql );
        }
        /* Add default options */
        if ( !get_option( 'doifd_list_options' ) ) {
            $doifd_default_options = array (
                'list_email_name' => '',
                'list_from_email' => '',
                'list_email_subject' => '',
                'list_send_html' => '0',
                'list_email_message' => __( 'Dear {subscriber},

Thank you for subscribing to {download}.

Please click the below link to confirm your subscription.

{url}

Thank You', 'doifd-list' )
            );

            add_option( 'doifd_list_options', $doifd_default_options );
        }
    }

    /* Fired for each blog when the plugin is deactivated. */

    private static function single_deactivate() {
        // @TODO: Define deactivation functionality here
    }

    /* Load the plugin text domain for translation. */

    public function load_plugin_textdomain() {

        $domain = $this->plugin_slug;
        $locale = apply_filters( 'plugin_locale', get_locale(), $domain );

        load_textdomain( $domain, trailingslashit( WP_LANG_DIR ) . $domain . '/' . $domain . '-' . $locale . '.mo' );
        load_plugin_textdomain( $domain, FALSE, basename( plugin_dir_path( dirname( __FILE__ ) ) ) . '/languages/' );
    }

    public static function save_activation_error_lists() {

        file_put_contents( ABSPATH . 'wp-content/uploads/doifd_downloads/error_list_activation.html', ob_get_contents() );
    }

    public function new_success_msg( $msg, $download_id ) {
        
        include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

        global $wpdb;
         
        if ( is_plugin_active( 'premium-double-opt-in-for-download/premium-double-opt-in-for-download.php' ) ) {
        
        /* Lets get the download_type to see if it's a download or a list. */
         
            $type = $wpdb->get_row( "SELECT doifd_download_type, doifd_download_tumessage
                                                    FROM " . $wpdb->prefix . "doifd_lab_downloads
                                                    WHERE doifd_download_id = $download_id " );
         
        /* Return success message depending on download type. 0 = download, 1 = list */

        if ( $type->doifd_download_type == '1' ) {
            
            if (!empty($type->doifd_download_tumessage)) {

            $msg = '<div class="doifd_success_msg">' . $type->doifd_download_tumessage . '</div>';
                
            } else {

            $msg = '<div class="doifd_success_msg"><h4>' . __( 'Thank You for Registering!', $this->plugin_slug ) . '<br />' . __( 'Please check your email to confirm your subscription.', $this->plugin_slug ) . '</h4><br /><i>' . __( 'Don\'t forget to check your junk or spam folder.', $this->plugin_slug ) . '</i></div>';
            
            }
            
            echo $msg;
            die();
            
                
        }

        if ( $type->doifd_download_type == '0' ) {
            
            if (!empty($type->doifd_download_tumessage)) {

            $msg = '<div class="doifd_success_msg">' . $type->doifd_download_tumessage . '</div>';
                
            } else {

            $msg = '<div class="doifd_success_msg"><h4>' . __( 'Thank You for Registering!', $this->plugin_slug ) . '<br />' . __( 'Please check your email for your link to your Free download.', $this->plugin_slug ) . '</h4><br /><i>' . __( 'Don\'t forget to check your junk or spam folder.', $this->plugin_slug ) . '</i></div>';
            
            }
            
            echo $msg;
            die();
            
        }
        
        } else {
            
            /* Lets get the download_type to see if it's a download or a list. */
         $type = $wpdb->get_row( "SELECT doifd_download_type
                                                    FROM " . $wpdb->prefix . "doifd_lab_downloads
                                                    WHERE doifd_download_id = $download_id " );
            
             /* Return success message depending on download type. 0 = download, 1 = list */

        if ( $type->doifd_download_type == '1' ) {

            $msg = '<div class="doifd_user_reg_form thankyou">
                    <h4>' . __( 'Thank You for Registering!', $this->plugin_slug ) . '<br />' . __( 'Please check your email to confirm your subscription.', $this->plugin_slug ) . '</h4><br /><i>' . __( 'Don\'t forget to check your junk or spam folder.', $this->plugin_slug ) . '</i><br /></div>';
            
        }

        if ( $type->doifd_download_type == '0' ) {

            $msg = '<div class="doifd_user_reg_form thankyou">
                    <h4>' . __( 'Thank You for Registering!', $this->plugin_slug ) . '<br />' . __( 'Please check your email for your link to your Free download.', $this->plugin_slug ) . '</h4><br /><i>' . __( 'Don\'t forget to check your junk or spam folder.', $this->plugin_slug ) . '</i></div>';
          
        }
        
        return $msg;
            
        }
    }
    
        public function new_widget_success_msg( $msg, $download_id ) {
            
         global $wpdb;
            
            /* Lets get the download_type to see if it's a download or a list. */
         $type = $wpdb->get_row( "SELECT doifd_download_type
                                                    FROM " . $wpdb->prefix . "doifd_lab_downloads
                                                    WHERE doifd_download_id = $download_id " );
            
             /* Return success message depending on download type. 0 = download, 1 = list */

        if ( $type->doifd_download_type == '1' ) {

            $msg = '<div id="widget_doifd_user_reg_form" class="thankyou">
                    <h4 id="widget_h4" class="widget_h4">' . __( 'Thank You for Registering!', $this->plugin_slug ) . '<br />' . __( 'Please check your email to confirm your subscription.', $this->plugin_slug ) . '</h4><br /><i>' . __( 'Don\'t forget to check your junk or spam folder.', $this->plugin_slug ) . '</i><br /></div>';
            
        }

        if ( $type->doifd_download_type == '0' ) {

            $msg = '<div id="widget_doifd_user_reg_form" class="thankyou">
                    <h4 id="widget_h4" class="widget_h4">' . __( 'Thank You for Registering!', $this->plugin_slug ) . '<br />' . __( 'Please check your email for your link to your Free download.', $this->plugin_slug ) . '</h4><br /><i>' . __( 'Don\'t forget to check your junk or spam folder.', $this->plugin_slug ) . '</i></div>';
          
        }
        
        echo $msg;
            
    }

    public function change_admin_email_subject( $subject, $download_id ) {

        global $wpdb;

        /* Lets get the download_type to see if it's a download or a list. */

        $type = $wpdb->get_row( "SELECT doifd_download_type
                                                    FROM " . $wpdb->prefix . "doifd_lab_downloads
                                                    WHERE doifd_download_id = $download_id " );

        /* Return success message depending on download type. 0 = download, 1 = list */

        if ( $type->doifd_download_type == '1' ) {

            $subject = '[New Subscriber] @ ' . get_bloginfo( 'name' );
            return $subject;
        }
        elseif ( $type->doifd_download_type == '0' ) {

            $subject = '[New Download] @ ' . get_bloginfo( 'name' );
            return $subject;
        }
        else {

            return $subject;
        }
    }

}